@@ -2,8 +2,10 @@ from abc import ABC, abstractmethod
 from asyncio.log import logger
 import json
 from requests import Response
-from syncari.models.request import (DescribeRequest, ErrorResponse,
+from syncari.models.request import (DescribeRequest, ErrorResponse, ReadResponse,
     SyncRequest, WebhookRequest, RequestType, Request)
+from syncari.models.core import Connection, EventData, Record, Result, SynapseInfo
+from syncari.models.schema import Schema
 from syncari.rest.client import SyncariException
 from ..logger import SyncariLogger
 
@@ -34,35 +36,56 @@ class Synapse(ABC):
 
             if self.request_type == RequestType.CONNECT:
                 response = self.connect()
+                assert isinstance(response, Connection)
             elif self.request_type == RequestType.SYNAPSE_INFO:
                 response = self.synapse_info()
+                assert isinstance(response, SynapseInfo)
             elif self.request_type == RequestType.DESCRIBE:
                 self.request = DescribeRequest.parse_obj(self.raw_request.body)
                 response = self.describe()
+                assert isinstance(response, list)
+                for val in response:
+                    assert isinstance(val, Schema)
             elif self.request_type == RequestType.READ:
                 self.request = SyncRequest.parse_obj(self.raw_request.body)
                 response = self.read()
+                assert isinstance(response, ReadResponse)
             elif self.request_type == RequestType.GET:
                 self.request = SyncRequest.parse_obj(self.raw_request.body)
                 response = self.get()
+                assert isinstance(response, list)
+                for val in response:
+                    assert isinstance(val, Record)
             elif self.request_type == RequestType.CREATE:
                 self.request = SyncRequest.parse_obj(self.raw_request.body)
                 response = self.create()
+                assert isinstance(response, list)
+                for val in response:
+                    assert isinstance(val, Result)
             elif self.request_type == RequestType.UPDATE:
                 self.request = SyncRequest.parse_obj(self.raw_request.body)
                 response = self.update()
+                assert isinstance(response, list)
+                for val in response:
+                    assert isinstance(val, Result)
             elif self.request_type == RequestType.DELETE:
                 self.request = SyncRequest.parse_obj(self.raw_request.body)
                 response = self.delete()
+                assert isinstance(response, list)
+                for val in response:
+                    assert isinstance(val, Result)
             elif self.request_type == RequestType.EXTRACT_WEBHOOK_IDENTIFIER:
                 self.request = WebhookRequest.parse_obj(self.raw_request.body)
                 response = self.extract_webhook_identifier()
+                assert isinstance(response, str)
             elif self.request_type == RequestType.PROCESS_WEBHOOK:
                 self.request = WebhookRequest.parse_obj(self.raw_request.body)
                 response = self.process_webhook()
+                assert isinstance(response, list)
+                for val in response:
+                    assert isinstance(val, EventData)
             else:
-                self.request = SyncRequest.parse_obj(self.raw_request.body)
-                response = self.read()
+                raise Exception('Invalid synapse request {}'.format(self.request_type))
 
         except SyncariException as e:
             response = e.error_response
